@@ -5,7 +5,7 @@ import json
 
 class Logger:
     def __init__(self, config_dict: dict = None):
-        if self.config_dict is not None:
+        if config_dict is not None:
             self.config_dict = config_dict
         else:
             self.config_dict = {
